<!DOCTYPE html>
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8">
    <%= stylesheet_link_tag "email" %>
  </head>
  <body>
    <h1>Normal email</h1>
    <div class="image"></div>
  </body>
</html>
